[omnibox] Update third_party/metrics_proto to match internal protos

This just runs the blaze command to roll metrics_proto to match the
latest internal version.

Bug: 963680
Change-Id: I4a36fc15b03476241928052fb59d0b907fc0b000
Reviewed-on: https://chromium-review.googlesource.com/c/chromium/src/+/1620006
Reviewed-by: Mark Pearson <mpearson@chromium.org>
Commit-Queue: Tommy Li <tommycli@chromium.org>
Cr-Commit-Position: refs/heads/master@{#661440}
diff --git a/third_party/metrics_proto/README.chromium b/third_party/metrics_proto/README.chromium
index 8b07105..17d206c 100644
--- a/third_party/metrics_proto/README.chromium
+++ b/third_party/metrics_proto/README.chromium
@@ -1,8 +1,8 @@
 Name: Metrics Protos
 Short Name: metrics_proto
 URL: This is the canonical public repository
-Version: 248273902
-Date: 2019/05/15 UTC
+Version: 249077303
+Date: 2019/05/20 UTC
 License: BSD
 Security Critical: Yes
 
diff --git a/third_party/metrics_proto/omnibox_event.proto b/third_party/metrics_proto/omnibox_event.proto
index 2daebc55..2f15966 100644
--- a/third_party/metrics_proto/omnibox_event.proto
+++ b/third_party/metrics_proto/omnibox_event.proto
@@ -122,8 +122,10 @@
     // The instant new tab page enum value was deprecated on August 2, 2013.
     OBSOLETE_INSTANT_NTP = 5;
 
-    // The search term replacement enum value was deprecated in August 2016.
-    OBSOLETE_SEARCH_RESULT_PAGE_DOING_SEARCH_TERM_REPLACEMENT = 6;
+    // The user is on a search result page that does search term replacement.
+    // This means the search terms are shown in the omnibox instead of the URL.
+    // In other words: Query in Omnibox is Active for this SRP.
+    SEARCH_RESULT_PAGE_DOING_SEARCH_TERM_REPLACEMENT = 6;
 
     // The new tab page in which this omnibox interaction first started
     // with the user having focus in the omnibox.
@@ -133,9 +135,9 @@
     // with the user having focus in the fakebox.
     INSTANT_NTP_WITH_FAKEBOX_AS_STARTING_FOCUS = 8;
 
-    // The user is on a search result page that's not doing search term
-    // replacement, meaning the URL of the page should've appeared in the
-    // omnibox before the user started editing it, not the search terms.
+    // The user is on a search result page that does not do search term
+    // replacement. This means the URL of the SRP is shown in the omnibox.
+    // In other words: Query in Omnibox is Inactive for this SRP.
     SEARCH_RESULT_PAGE_NO_SEARCH_TERM_REPLACEMENT = 9;
 
     // The user is on the home screen.
diff --git a/third_party/metrics_proto/sampled_profile.proto b/third_party/metrics_proto/sampled_profile.proto
index 5cf5650..c5da7e5 100644
--- a/third_party/metrics_proto/sampled_profile.proto
+++ b/third_party/metrics_proto/sampled_profile.proto
@@ -19,7 +19,7 @@
 // Protocol buffer for collected sample-based profiling data.
 // Contains the parameters and data from a single profile collection event.
 
-// Next tag: 15
+// Next tag: 16
 message SampledProfile {
   // Indicates the event that triggered this collection.
   enum TriggerEvent {
@@ -107,4 +107,11 @@
 
   // Perf counter data collected using "perf stat".
   optional PerfStatProto perf_stat = 10;
+
+  // The maximum frequency in MHz reported for each logical CPU on the device.
+  // This is a repeated field, where entry 0 corresponds to core 0, entry 1 to
+  // core 1, and so on. The field is optional and populated only for metrics
+  // that can use the max frequency to compute a CPU utilization metric, e.g.
+  // when measuring CPU cycles.
+  repeated uint32 cpu_max_frequency_mhz = 15;
 }
diff --git a/third_party/metrics_proto/extension_install.proto b/third_party/metrics_proto/extension_install.proto
index 755daca2..e4e6398f 100644
--- a/third_party/metrics_proto/extension_install.proto
+++ b/third_party/metrics_proto/extension_install.proto
@@ -16,14 +16,15 @@
 message ExtensionInstallProto {
   // The type of extension item this is.
   enum Type {
-    UNKNOWN_TYPE = 0;         // Unknown (hopefully never used)
-    EXTENSION = 1;            // A browser extension
-    THEME = 2;                // A browser theme
-    USER_SCRIPT = 3;          // An extension converted from a user script
-    HOSTED_APP = 4;           // A hosted app
-    LEGACY_PACKAGED_APP = 5;  // A (deprecated) v1 packaged app
-    PLATFORM_APP = 6;         // A platform app
-    SHARED_MODULE = 7;        // A shared module
+    UNKNOWN_TYPE = 0;            // Unknown (hopefully never used)
+    EXTENSION = 1;               // A browser extension
+    THEME = 2;                   // A browser theme
+    USER_SCRIPT = 3;             // An extension converted from a user script
+    HOSTED_APP = 4;              // A hosted app
+    LEGACY_PACKAGED_APP = 5;     // A (deprecated) v1 packaged app
+    PLATFORM_APP = 6;            // A platform app
+    SHARED_MODULE = 7;           // A shared module
+    LOGIN_SCREEN_EXTENSION = 8;  // An extension running on the login screen
   }
   optional Type type = 1;
 